# Help improving the speed of a DataFrames operation

**URL:** <https://discourse.julialang.org/t/help-improving-the-speed-of-a-dataframes-operation/107615>\
**Category:** Performance\
**Tags:** performance, query, dataframes\
**Created:** [December 14, 2023, 3:20pm UTC](https://discourse.julialang.org/t/help-improving-the-speed-of-a-dataframes-operation/107615 "2023-12-14T15:20:21Z")\
**Posts on this page:** 1\
**Showing post:** 38

<div class="post-metadata">

**Author:** ![abelsiqueira](https://sea2.discourse-cdn.com/julialang/user_avatar/discourse.julialang.org/abelsiqueira/32/47269_2.png) [@abelsiqueira](https://discourse.julialang.org/u/abelsiqueira)\
**Post date:** [February 22, 2024, 9:25am UTC](https://discourse.julialang.org/t/help-improving-the-speed-of-a-dataframes-operation/107615/38 "2024-02-22T09:25:18Z")

</div>

Hey, sorry for the lack of replies, I went on vacation in December and forgot to reply in January.

For completion: We’ve implement a solution based on @Dan’s reply: [TulipaEnergyModel.jl/src/create-model.jl at e2b5e8891a4edbfa0c1043847f7a56b146d6f00d · TulipaEnergy/TulipaEnergyModel.jl · GitHub](https://github.com/TulipaEnergy/TulipaEnergyModel.jl/blob/e2b5e8891a4edbfa0c1043847f7a56b146d6f00d/src/create-model.jl#L66) and it was merged a few weeks ago.

I haven’t checked your latest solution @rocco_sprmnt21, so I don’t know how it compares. It is not easy to test it with the current code, so I will have to park it for now.  
With the improvements that we made, we decided that it is good enough for now, and moved to finished some other more pressing objectives. We will come back to performance later, so I might revisit this in the future.

The merged version was [3.2 times faster](https://github.com/TulipaEnergy/TulipaEnergyModel.jl/pull/407#issuecomment-1887416560) than what we had!

Thank you all for the help.

---

_[View the full topic](https://discourse.julialang.org/t/help-improving-the-speed-of-a-dataframes-operation/107615)._
